@@ -1,5 +1,5 @@
-import os
 from .utils import run_command
+from .vcpkg import vcpkg_executable_name
 
 # -----------------------------------------------------------------------------
 
@@ -8,11 +8,9 @@ def handle_add_command(packages_to_add):
         print("Error: No packages specified to add.")
         return
 
-    if os.name == "posix":
-        path_to_vcpkg = "vcpkg/vcpkg"
-    else:
-        path_to_vcpkg = "vcpkg/vcpkg.exe"
-    vcpkg_add_port = [path_to_vcpkg, "add", "port"]
+    vcpkg = vcpkg_executable_name()
+
+    vcpkg_add_port = [vcpkg, "add", "port"]
     vcpkg_add_port.extend(packages_to_add)
 
     run_command(vcpkg_add_port)
